# PEAS
## Proximal Enrichment by Approximated Sampling

PEAS provides a pipeline to compute optimal sets of enriched or depleted signal in either a 1-D vector or 2-D matrix. 

It also includes a module and command-line script that apply this method to the problem of finding such enriched or depleted areas of differences or correlations between columns of a genomic peak matrix.    
